Status

Struct Status 

pub struct Status {
    pub running: Option<bool>,
    pub runs: Option<u32>,
    pub elapsed: Option<i64>,
    pub covered_pcs: Option<u64>,
    pub covered_features: Option<u64>,
    pub corpus_num_inputs: Option<u64>,
    pub corpus_total_size: Option<u64>,
    pub process_stats: Option<Vec<ProcessStats>>,
    /* private fields */
}
See Controller.GetStatus.

Fields

running: Option<bool>

True if the fuzzer is working on a commands, e.g. it is fuzzing.

runs: Option<u32>

Number of runs performed so far.

elapsed: Option<i64>

Time spent so far.

covered_pcs: Option<u64>

Number of program edges covered so far.

covered_features: Option<u64>

Number of opaque features encountered so far.

corpus_num_inputs: Option<u64>

Number of inputs in the “live” corpus.

corpus_total_size: Option<u64>

Total size of the inputs in the “live” corpus.

process_stats: Option<Vec<ProcessStats>>

Information about the instrumented processes attached to the engine.